# author: Achim Gaedke
# created: May 2001
# file: pygsl/__init__.py
# $Id: __init__.py,v 1.1.1.1 2001/12/13 16:04:11 achimgaedke Exp $

import pygsl.init

version="0.0.4"
__all__=['sf','const','ieee','rng','errors']
