{"airy_Ai",gsl_sf_airy_Ai_e_wrap,METH_VARARGS},
{"airy_Bi",gsl_sf_airy_Bi_e_wrap,METH_VARARGS},
{"airy_Ai_scaled",gsl_sf_airy_Ai_scaled_e_wrap,METH_VARARGS},
{"airy_Bi_scaled",gsl_sf_airy_Bi_scaled_e_wrap,METH_VARARGS},
{"airy_Ai_deriv",gsl_sf_airy_Ai_deriv_e_wrap,METH_VARARGS},
{"airy_Bi_deriv",gsl_sf_airy_Bi_deriv_e_wrap,METH_VARARGS},
{"airy_Ai_deriv_scaled",gsl_sf_airy_Ai_deriv_scaled_e_wrap,METH_VARARGS},
{"airy_Bi_deriv_scaled",gsl_sf_airy_Bi_deriv_scaled_e_wrap,METH_VARARGS},
{"airy_zero_Ai",gsl_sf_airy_zero_Ai_e_wrap,METH_VARARGS},
{"airy_zero_Bi",gsl_sf_airy_zero_Bi_e_wrap,METH_VARARGS},
{"airy_zero_Ai_deriv",gsl_sf_airy_zero_Ai_deriv_e_wrap,METH_VARARGS},
{"airy_zero_Bi_deriv",gsl_sf_airy_zero_Bi_deriv_e_wrap,METH_VARARGS},
{"bessel_J0",gsl_sf_bessel_J0_e_wrap,METH_VARARGS},
{"bessel_J1",gsl_sf_bessel_J1_e_wrap,METH_VARARGS},
{"bessel_Jn",gsl_sf_bessel_Jn_e_wrap,METH_VARARGS},
{"bessel_Y0",gsl_sf_bessel_Y0_e_wrap,METH_VARARGS},
{"bessel_Y1",gsl_sf_bessel_Y1_e_wrap,METH_VARARGS},
{"bessel_Yn",gsl_sf_bessel_Yn_e_wrap,METH_VARARGS},
{"bessel_I0",gsl_sf_bessel_I0_e_wrap,METH_VARARGS},
{"bessel_I1",gsl_sf_bessel_I1_e_wrap,METH_VARARGS},
{"bessel_In",gsl_sf_bessel_In_e_wrap,METH_VARARGS},
{"bessel_I0_scaled",gsl_sf_bessel_I0_scaled_e_wrap,METH_VARARGS},
{"bessel_I1_scaled",gsl_sf_bessel_I1_scaled_e_wrap,METH_VARARGS},
{"bessel_In_scaled",gsl_sf_bessel_In_scaled_e_wrap,METH_VARARGS},
{"bessel_K0",gsl_sf_bessel_K0_e_wrap,METH_VARARGS},
{"bessel_K1",gsl_sf_bessel_K1_e_wrap,METH_VARARGS},
{"bessel_Kn",gsl_sf_bessel_Kn_e_wrap,METH_VARARGS},
{"bessel_K0_scaled",gsl_sf_bessel_K0_scaled_e_wrap,METH_VARARGS},
{"bessel_K1_scaled",gsl_sf_bessel_K1_scaled_e_wrap,METH_VARARGS},
{"bessel_Kn_scaled",gsl_sf_bessel_Kn_scaled_e_wrap,METH_VARARGS},
{"bessel_j0",gsl_sf_bessel_j0_e_wrap,METH_VARARGS},
{"bessel_j1",gsl_sf_bessel_j1_e_wrap,METH_VARARGS},
{"bessel_j2",gsl_sf_bessel_j2_e_wrap,METH_VARARGS},
{"bessel_jl",gsl_sf_bessel_jl_e_wrap,METH_VARARGS},
{"bessel_y0",gsl_sf_bessel_y0_e_wrap,METH_VARARGS},
{"bessel_y1",gsl_sf_bessel_y1_e_wrap,METH_VARARGS},
{"bessel_y2",gsl_sf_bessel_y2_e_wrap,METH_VARARGS},
{"bessel_yl",gsl_sf_bessel_yl_e_wrap,METH_VARARGS},
{"bessel_i0_scaled",gsl_sf_bessel_i0_scaled_e_wrap,METH_VARARGS},
{"bessel_i1_scaled",gsl_sf_bessel_i1_scaled_e_wrap,METH_VARARGS},
{"bessel_i2_scaled",gsl_sf_bessel_i2_scaled_e_wrap,METH_VARARGS},
{"bessel_il_scaled",gsl_sf_bessel_il_scaled_e_wrap,METH_VARARGS},
{"bessel_k0_scaled",gsl_sf_bessel_k0_scaled_e_wrap,METH_VARARGS},
{"bessel_k1_scaled",gsl_sf_bessel_k1_scaled_e_wrap,METH_VARARGS},
{"bessel_k2_scaled",gsl_sf_bessel_k2_scaled_e_wrap,METH_VARARGS},
{"bessel_kl_scaled",gsl_sf_bessel_kl_scaled_e_wrap,METH_VARARGS},
{"bessel_Jnu",gsl_sf_bessel_Jnu_e_wrap,METH_VARARGS},
{"bessel_Ynu",gsl_sf_bessel_Ynu_e_wrap,METH_VARARGS},
{"bessel_Inu_scaled",gsl_sf_bessel_Inu_scaled_e_wrap,METH_VARARGS},
{"bessel_Inu",gsl_sf_bessel_Inu_e_wrap,METH_VARARGS},
{"bessel_Knu_scaled",gsl_sf_bessel_Knu_scaled_e_wrap,METH_VARARGS},
{"bessel_Knu",gsl_sf_bessel_Knu_e_wrap,METH_VARARGS},
{"bessel_lnKnu",gsl_sf_bessel_lnKnu_e_wrap,METH_VARARGS},
{"bessel_zero_J0",gsl_sf_bessel_zero_J0_e_wrap,METH_VARARGS},
{"bessel_zero_J1",gsl_sf_bessel_zero_J1_e_wrap,METH_VARARGS},
{"bessel_zero_Jnu",gsl_sf_bessel_zero_Jnu_e_wrap,METH_VARARGS},
{"clausen",gsl_sf_clausen_e_wrap,METH_VARARGS},
{"coupling_3j",gsl_sf_coupling_3j_e_wrap,METH_VARARGS},
{"coupling_6j",gsl_sf_coupling_6j_e_wrap,METH_VARARGS},
{"coupling_9j",gsl_sf_coupling_9j_e_wrap,METH_VARARGS},
{"hydrogenicR_1",gsl_sf_hydrogenicR_1_e_wrap,METH_VARARGS},
{"hydrogenicR",gsl_sf_hydrogenicR_e_wrap,METH_VARARGS},
{"coulomb_wave_FG",gsl_sf_coulomb_wave_FG_e_wrap,METH_VARARGS},
{"coulomb_CL",gsl_sf_coulomb_CL_e_wrap,METH_VARARGS},
{"dawson",gsl_sf_dawson_e_wrap,METH_VARARGS},
{"debye_1",gsl_sf_debye_1_e_wrap,METH_VARARGS},
{"debye_2",gsl_sf_debye_2_e_wrap,METH_VARARGS},
{"debye_3",gsl_sf_debye_3_e_wrap,METH_VARARGS},
{"debye_4",gsl_sf_debye_4_e_wrap,METH_VARARGS},
{"dilog",gsl_sf_dilog_e_wrap,METH_VARARGS},
{"complex_dilog",gsl_sf_complex_dilog_e_wrap,METH_VARARGS},
{"multiply",gsl_sf_multiply_e_wrap,METH_VARARGS},
{"multiply_err",gsl_sf_multiply_err_e_wrap,METH_VARARGS},
{"ellint_Kcomp",gsl_sf_ellint_Kcomp_e_wrap,METH_VARARGS},
{"ellint_Ecomp",gsl_sf_ellint_Ecomp_e_wrap,METH_VARARGS},
{"ellint_F",gsl_sf_ellint_F_e_wrap,METH_VARARGS},
{"ellint_E",gsl_sf_ellint_E_e_wrap,METH_VARARGS},
{"ellint_P",gsl_sf_ellint_P_e_wrap,METH_VARARGS},
{"ellint_D",gsl_sf_ellint_D_e_wrap,METH_VARARGS},
{"ellint_RC",gsl_sf_ellint_RC_e_wrap,METH_VARARGS},
{"ellint_RD",gsl_sf_ellint_RD_e_wrap,METH_VARARGS},
{"ellint_RF",gsl_sf_ellint_RF_e_wrap,METH_VARARGS},
{"ellint_RJ",gsl_sf_ellint_RJ_e_wrap,METH_VARARGS},
{"elljac",gsl_sf_elljac_e_wrap,METH_VARARGS},
{"erfc",gsl_sf_erfc_e_wrap,METH_VARARGS},
{"log_erfc",gsl_sf_log_erfc_e_wrap,METH_VARARGS},
{"erf",gsl_sf_erf_e_wrap,METH_VARARGS},
{"erf_Z",gsl_sf_erf_Z_e_wrap,METH_VARARGS},
{"erf_Q",gsl_sf_erf_Q_e_wrap,METH_VARARGS},
{"expint_E1",gsl_sf_expint_E1_e_wrap,METH_VARARGS},
{"expint_E2",gsl_sf_expint_E2_e_wrap,METH_VARARGS},
{"expint_Ei",gsl_sf_expint_Ei_e_wrap,METH_VARARGS},
{"Shi",gsl_sf_Shi_e_wrap,METH_VARARGS},
{"Chi",gsl_sf_Chi_e_wrap,METH_VARARGS},
{"expint_3",gsl_sf_expint_3_e_wrap,METH_VARARGS},
{"Si",gsl_sf_Si_e_wrap,METH_VARARGS},
{"Ci",gsl_sf_Ci_e_wrap,METH_VARARGS},
{"atanint",gsl_sf_atanint_e_wrap,METH_VARARGS},
{"fermi_dirac_m1",gsl_sf_fermi_dirac_m1_e_wrap,METH_VARARGS},
{"fermi_dirac_0",gsl_sf_fermi_dirac_0_e_wrap,METH_VARARGS},
{"fermi_dirac_1",gsl_sf_fermi_dirac_1_e_wrap,METH_VARARGS},
{"fermi_dirac_2",gsl_sf_fermi_dirac_2_e_wrap,METH_VARARGS},
{"fermi_dirac_int",gsl_sf_fermi_dirac_int_e_wrap,METH_VARARGS},
{"fermi_dirac_mhalf",gsl_sf_fermi_dirac_mhalf_e_wrap,METH_VARARGS},
{"fermi_dirac_half",gsl_sf_fermi_dirac_half_e_wrap,METH_VARARGS},
{"fermi_dirac_3half",gsl_sf_fermi_dirac_3half_e_wrap,METH_VARARGS},
{"fermi_dirac_inc_0",gsl_sf_fermi_dirac_inc_0_e_wrap,METH_VARARGS},
{"lngamma",gsl_sf_lngamma_e_wrap,METH_VARARGS},
{"lngamma_sgn",gsl_sf_lngamma_sgn_e_wrap,METH_VARARGS},
{"gamma",gsl_sf_gamma_e_wrap,METH_VARARGS},
{"gammastar",gsl_sf_gammastar_e_wrap,METH_VARARGS},
{"gammainv",gsl_sf_gammainv_e_wrap,METH_VARARGS},
{"lngamma_complex",gsl_sf_lngamma_complex_e_wrap,METH_VARARGS},
{"taylorcoeff",gsl_sf_taylorcoeff_e_wrap,METH_VARARGS},
{"fact",gsl_sf_fact_e_wrap,METH_VARARGS},
{"doublefact",gsl_sf_doublefact_e_wrap,METH_VARARGS},
{"lnfact",gsl_sf_lnfact_e_wrap,METH_VARARGS},
{"lndoublefact",gsl_sf_lndoublefact_e_wrap,METH_VARARGS},
{"lnchoose",gsl_sf_lnchoose_e_wrap,METH_VARARGS},
{"choose",gsl_sf_choose_e_wrap,METH_VARARGS},
{"lnpoch",gsl_sf_lnpoch_e_wrap,METH_VARARGS},
{"lnpoch_sgn",gsl_sf_lnpoch_sgn_e_wrap,METH_VARARGS},
{"poch",gsl_sf_poch_e_wrap,METH_VARARGS},
{"pochrel",gsl_sf_pochrel_e_wrap,METH_VARARGS},
{"gamma_inc_Q",gsl_sf_gamma_inc_Q_e_wrap,METH_VARARGS},
{"gamma_inc_P",gsl_sf_gamma_inc_P_e_wrap,METH_VARARGS},
{"lnbeta",gsl_sf_lnbeta_e_wrap,METH_VARARGS},
{"beta",gsl_sf_beta_e_wrap,METH_VARARGS},
{"beta_inc",gsl_sf_beta_inc_e_wrap,METH_VARARGS},
{"gegenpoly_1",gsl_sf_gegenpoly_1_e_wrap,METH_VARARGS},
{"gegenpoly_2",gsl_sf_gegenpoly_2_e_wrap,METH_VARARGS},
{"gegenpoly_3",gsl_sf_gegenpoly_3_e_wrap,METH_VARARGS},
{"gegenpoly_n",gsl_sf_gegenpoly_n_e_wrap,METH_VARARGS},
{"hyperg_0F1",gsl_sf_hyperg_0F1_e_wrap,METH_VARARGS},
{"hyperg_1F1_int",gsl_sf_hyperg_1F1_int_e_wrap,METH_VARARGS},
{"hyperg_1F1",gsl_sf_hyperg_1F1_e_wrap,METH_VARARGS},
{"hyperg_U_int",gsl_sf_hyperg_U_int_e_wrap,METH_VARARGS},
{"hyperg_U_int_e10",gsl_sf_hyperg_U_int_e10_e_wrap,METH_VARARGS},
{"hyperg_U",gsl_sf_hyperg_U_e_wrap,METH_VARARGS},
{"hyperg_U_e10",gsl_sf_hyperg_U_e10_e_wrap,METH_VARARGS},
{"hyperg_2F1",gsl_sf_hyperg_2F1_e_wrap,METH_VARARGS},
{"hyperg_2F1_conj",gsl_sf_hyperg_2F1_conj_e_wrap,METH_VARARGS},
{"hyperg_2F1_renorm",gsl_sf_hyperg_2F1_renorm_e_wrap,METH_VARARGS},
{"hyperg_2F1_conj_renorm",gsl_sf_hyperg_2F1_conj_renorm_e_wrap,METH_VARARGS},
{"hyperg_2F0",gsl_sf_hyperg_2F0_e_wrap,METH_VARARGS},
{"laguerre_1",gsl_sf_laguerre_1_e_wrap,METH_VARARGS},
{"laguerre_2",gsl_sf_laguerre_2_e_wrap,METH_VARARGS},
{"laguerre_3",gsl_sf_laguerre_3_e_wrap,METH_VARARGS},
{"laguerre_n",gsl_sf_laguerre_n_e_wrap,METH_VARARGS},
{"lambert_W0",gsl_sf_lambert_W0_e_wrap,METH_VARARGS},
{"lambert_Wm1",gsl_sf_lambert_Wm1_e_wrap,METH_VARARGS},
{"legendre_Pl",gsl_sf_legendre_Pl_e_wrap,METH_VARARGS},
{"legendre_P1",gsl_sf_legendre_P1_e_wrap,METH_VARARGS},
{"legendre_P2",gsl_sf_legendre_P2_e_wrap,METH_VARARGS},
{"legendre_P3",gsl_sf_legendre_P3_e_wrap,METH_VARARGS},
{"legendre_Q0",gsl_sf_legendre_Q0_e_wrap,METH_VARARGS},
{"legendre_Q1",gsl_sf_legendre_Q1_e_wrap,METH_VARARGS},
{"legendre_Ql",gsl_sf_legendre_Ql_e_wrap,METH_VARARGS},
{"legendre_Plm",gsl_sf_legendre_Plm_e_wrap,METH_VARARGS},
{"legendre_sphPlm",gsl_sf_legendre_sphPlm_e_wrap,METH_VARARGS},
{"conicalP_half",gsl_sf_conicalP_half_e_wrap,METH_VARARGS},
{"conicalP_mhalf",gsl_sf_conicalP_mhalf_e_wrap,METH_VARARGS},
{"conicalP_0",gsl_sf_conicalP_0_e_wrap,METH_VARARGS},
{"conicalP_1",gsl_sf_conicalP_1_e_wrap,METH_VARARGS},
{"conicalP_sph_reg",gsl_sf_conicalP_sph_reg_e_wrap,METH_VARARGS},
{"conicalP_cyl_reg",gsl_sf_conicalP_cyl_reg_e_wrap,METH_VARARGS},
{"legendre_H3d_0",gsl_sf_legendre_H3d_0_e_wrap,METH_VARARGS},
{"legendre_H3d_1",gsl_sf_legendre_H3d_1_e_wrap,METH_VARARGS},
{"legendre_H3d",gsl_sf_legendre_H3d_e_wrap,METH_VARARGS},
{"log",gsl_sf_log_e_wrap,METH_VARARGS},
{"log_abs",gsl_sf_log_abs_e_wrap,METH_VARARGS},
{"complex_log",gsl_sf_complex_log_e_wrap,METH_VARARGS},
{"log_1plusx",gsl_sf_log_1plusx_e_wrap,METH_VARARGS},
{"log_1plusx_mx",gsl_sf_log_1plusx_mx_e_wrap,METH_VARARGS},
{"pow_int",gsl_sf_pow_int_e_wrap,METH_VARARGS},
{"psi_int",gsl_sf_psi_int_e_wrap,METH_VARARGS},
{"psi",gsl_sf_psi_e_wrap,METH_VARARGS},
{"psi_1piy",gsl_sf_psi_1piy_e_wrap,METH_VARARGS},
{"psi_1_int",gsl_sf_psi_1_int_e_wrap,METH_VARARGS},
{"psi_n",gsl_sf_psi_n_e_wrap,METH_VARARGS},
{"synchrotron_1",gsl_sf_synchrotron_1_e_wrap,METH_VARARGS},
{"synchrotron_2",gsl_sf_synchrotron_2_e_wrap,METH_VARARGS},
{"transport_2",gsl_sf_transport_2_e_wrap,METH_VARARGS},
{"transport_3",gsl_sf_transport_3_e_wrap,METH_VARARGS},
{"transport_4",gsl_sf_transport_4_e_wrap,METH_VARARGS},
{"transport_5",gsl_sf_transport_5_e_wrap,METH_VARARGS},
{"sin",gsl_sf_sin_e_wrap,METH_VARARGS},
{"cos",gsl_sf_cos_e_wrap,METH_VARARGS},
{"hypot",gsl_sf_hypot_e_wrap,METH_VARARGS},
{"complex_sin",gsl_sf_complex_sin_e_wrap,METH_VARARGS},
{"complex_cos",gsl_sf_complex_cos_e_wrap,METH_VARARGS},
{"complex_logsin",gsl_sf_complex_logsin_e_wrap,METH_VARARGS},
{"sinc",gsl_sf_sinc_e_wrap,METH_VARARGS},
{"lnsinh",gsl_sf_lnsinh_e_wrap,METH_VARARGS},
{"lncosh",gsl_sf_lncosh_e_wrap,METH_VARARGS},
{"sin_err",gsl_sf_sin_err_e_wrap,METH_VARARGS},
{"cos_err",gsl_sf_cos_err_e_wrap,METH_VARARGS},
{"angle_restrict_symm_err",gsl_sf_angle_restrict_symm_err_e_wrap,METH_VARARGS},
{"angle_restrict_pos_err",gsl_sf_angle_restrict_pos_err_e_wrap,METH_VARARGS},
{"zeta_int",gsl_sf_zeta_int_e_wrap,METH_VARARGS},
{"zeta",gsl_sf_zeta_e_wrap,METH_VARARGS},
{"hzeta",gsl_sf_hzeta_e_wrap,METH_VARARGS},
{"eta_int",gsl_sf_eta_int_e_wrap,METH_VARARGS},
{"eta",gsl_sf_eta_e_wrap,METH_VARARGS},
