PyModule_AddObject(m,"cgs_speed_of_light",PyFloat_FromDouble((2.99792458e10) ));
PyModule_AddObject(m,"cgs_gravitational_constant",PyFloat_FromDouble((6.67259e-8) ));
PyModule_AddObject(m,"cgs_plancks_constant_h",PyFloat_FromDouble((6.6260755e-27) ));
PyModule_AddObject(m,"cgs_plancks_constant_hbar",PyFloat_FromDouble((1.05457266913e-27) ));
PyModule_AddObject(m,"cgs_vacuum_permeability",PyFloat_FromDouble((1.25663706144e-1) ));
PyModule_AddObject(m,"cgs_astronomical_unit",PyFloat_FromDouble((1.495979e13) ));
PyModule_AddObject(m,"cgs_light_year",PyFloat_FromDouble((9.46053620707e17) ));
PyModule_AddObject(m,"cgs_parsec",PyFloat_FromDouble((3.08567818589e18) ));
PyModule_AddObject(m,"cgs_grav_accel",PyFloat_FromDouble((9.80665e2) ));
PyModule_AddObject(m,"cgs_electron_volt",PyFloat_FromDouble((1.60217733e-12) ));
PyModule_AddObject(m,"cgs_mass_electron",PyFloat_FromDouble((9.10938961969e-28) ));
PyModule_AddObject(m,"cgs_mass_muon",PyFloat_FromDouble((1.88353269879e-25) ));
PyModule_AddObject(m,"cgs_mass_proton",PyFloat_FromDouble((1.67262307095e-24) ));
PyModule_AddObject(m,"cgs_mass_neutron",PyFloat_FromDouble((1.67492862142e-24) ));
PyModule_AddObject(m,"cgs_rydberg",PyFloat_FromDouble((2.17987412173e-11) ));
PyModule_AddObject(m,"cgs_boltzmann",PyFloat_FromDouble((1.3806513e-16) ));
PyModule_AddObject(m,"cgs_bohr_magneton",PyFloat_FromDouble((9.27401542715e-20) ));
PyModule_AddObject(m,"cgs_nuclear_magneton",PyFloat_FromDouble((5.05078658357e-23) ));
PyModule_AddObject(m,"cgs_electron_magnetic_moment",PyFloat_FromDouble((9.28477005945e-20) ));
PyModule_AddObject(m,"cgs_proton_magnetic_moment",PyFloat_FromDouble((1.41060761072e-22) ));
PyModule_AddObject(m,"cgs_molar_gas",PyFloat_FromDouble((8.31447086363e7) ));
PyModule_AddObject(m,"cgs_standard_gas_volume",PyFloat_FromDouble((2.2413992e4) ));
PyModule_AddObject(m,"cgs_minute",PyFloat_FromDouble((6e1) ));
PyModule_AddObject(m,"cgs_hour",PyFloat_FromDouble((3.6e3) ));
PyModule_AddObject(m,"cgs_day",PyFloat_FromDouble((8.64e4) ));
PyModule_AddObject(m,"cgs_week",PyFloat_FromDouble((6.048e5) ));
PyModule_AddObject(m,"cgs_inch",PyFloat_FromDouble((2.54e0) ));
PyModule_AddObject(m,"cgs_foot",PyFloat_FromDouble((3.048e1) ));
PyModule_AddObject(m,"cgs_yard",PyFloat_FromDouble((9.144e1) ));
PyModule_AddObject(m,"cgs_mile",PyFloat_FromDouble((1.609344e5) ));
PyModule_AddObject(m,"cgs_nautical_mile",PyFloat_FromDouble((1.852e5) ));
PyModule_AddObject(m,"cgs_fathom",PyFloat_FromDouble((1.8288e2) ));
PyModule_AddObject(m,"cgs_mil",PyFloat_FromDouble((2.54e-3) ));
PyModule_AddObject(m,"cgs_point",PyFloat_FromDouble((3.52777777778e-2) ));
PyModule_AddObject(m,"cgs_texpoint",PyFloat_FromDouble((3.51459803515e-2) ));
PyModule_AddObject(m,"cgs_micron",PyFloat_FromDouble((1e-4) ));
PyModule_AddObject(m,"cgs_angstrom",PyFloat_FromDouble((1e-8) ));
PyModule_AddObject(m,"cgs_hectare",PyFloat_FromDouble((1e8) ));
PyModule_AddObject(m,"cgs_acre",PyFloat_FromDouble((4.04685642241e7) ));
PyModule_AddObject(m,"cgs_barn",PyFloat_FromDouble((1e-24) ));
PyModule_AddObject(m,"cgs_liter",PyFloat_FromDouble((1e3) ));
PyModule_AddObject(m,"cgs_us_gallon",PyFloat_FromDouble((3.78541178402e3) ));
PyModule_AddObject(m,"cgs_quart",PyFloat_FromDouble((9.46352946004e2) ));
PyModule_AddObject(m,"cgs_pint",PyFloat_FromDouble((4.73176473002e2) ));
PyModule_AddObject(m,"cgs_cup",PyFloat_FromDouble((2.36588236501e2) ));
PyModule_AddObject(m,"cgs_fluid_ounce",PyFloat_FromDouble((2.95735295626e1) ));
PyModule_AddObject(m,"cgs_tablespoon",PyFloat_FromDouble((1.47867647813e1) ));
PyModule_AddObject(m,"cgs_teaspoon",PyFloat_FromDouble((4.92892159375e0) ));
PyModule_AddObject(m,"cgs_canadian_gallon",PyFloat_FromDouble((4.54609e3) ));
PyModule_AddObject(m,"cgs_uk_gallon",PyFloat_FromDouble((4.546092e3) ));
PyModule_AddObject(m,"cgs_miles_per_hour",PyFloat_FromDouble((4.4704e1) ));
PyModule_AddObject(m,"cgs_kilometers_per_hour",PyFloat_FromDouble((2.77777777778e1) ));
PyModule_AddObject(m,"cgs_knot",PyFloat_FromDouble((5.14444444444e1) ));
PyModule_AddObject(m,"cgs_pound_mass",PyFloat_FromDouble((4.5359237e2) ));
PyModule_AddObject(m,"cgs_ounce_mass",PyFloat_FromDouble((2.8349523125e1) ));
PyModule_AddObject(m,"cgs_ton",PyFloat_FromDouble((9.0718474e5) ));
PyModule_AddObject(m,"cgs_metric_ton",PyFloat_FromDouble((1e6) ));
PyModule_AddObject(m,"cgs_uk_ton",PyFloat_FromDouble((1.0160469088e6) ));
PyModule_AddObject(m,"cgs_troy_ounce",PyFloat_FromDouble((3.1103475e1) ));
PyModule_AddObject(m,"cgs_carat",PyFloat_FromDouble((2e-1) ));
PyModule_AddObject(m,"cgs_unified_atomic_mass",PyFloat_FromDouble((1.6605402e-24) ));
PyModule_AddObject(m,"cgs_gram_force",PyFloat_FromDouble((9.80665e2) ));
PyModule_AddObject(m,"cgs_pound_force",PyFloat_FromDouble((4.44822161526e5) ));
PyModule_AddObject(m,"cgs_kilopound_force",PyFloat_FromDouble((4.44822161526e8) ));
PyModule_AddObject(m,"cgs_poundal",PyFloat_FromDouble((1.38255e4) ));
PyModule_AddObject(m,"cgs_calorie",PyFloat_FromDouble((4.1868e7) ));
PyModule_AddObject(m,"cgs_btu",PyFloat_FromDouble((1.05505585262e10) ));
PyModule_AddObject(m,"cgs_therm",PyFloat_FromDouble((1.05506e15) ));
PyModule_AddObject(m,"cgs_horsepower",PyFloat_FromDouble((7.457e9) ));
PyModule_AddObject(m,"cgs_bar",PyFloat_FromDouble((1e6) ));
PyModule_AddObject(m,"cgs_std_atmosphere",PyFloat_FromDouble((1.01325e6) ));
PyModule_AddObject(m,"cgs_torr",PyFloat_FromDouble((1.33322368421e3) ));
PyModule_AddObject(m,"cgs_meter_of_mercury",PyFloat_FromDouble((1.33322368421e6) ));
PyModule_AddObject(m,"cgs_inch_of_mercury",PyFloat_FromDouble((3.38638815789e4) ));
PyModule_AddObject(m,"cgs_inch_of_water",PyFloat_FromDouble((2.4884e3) ));
PyModule_AddObject(m,"cgs_psi",PyFloat_FromDouble((6.89475729317e4) ));
PyModule_AddObject(m,"cgs_poise",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"cgs_stokes",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"cgs_faraday",PyFloat_FromDouble((9.6485308989e4) ));
PyModule_AddObject(m,"cgs_electron_charge",PyFloat_FromDouble((1.60217733e-19) ));
PyModule_AddObject(m,"cgs_gauss",PyFloat_FromDouble((1e-1) ));
PyModule_AddObject(m,"cgs_stilb",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"cgs_lumen",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"cgs_lux",PyFloat_FromDouble((1e-4) ));
PyModule_AddObject(m,"cgs_phot",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"cgs_footcandle",PyFloat_FromDouble((1.076e-3) ));
PyModule_AddObject(m,"cgs_lambert",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"cgs_footlambert",PyFloat_FromDouble((1.07639104e-3) ));
PyModule_AddObject(m,"cgs_curie",PyFloat_FromDouble((3.7e10) ));
PyModule_AddObject(m,"cgs_roentgen",PyFloat_FromDouble((2.58e-7) ));
PyModule_AddObject(m,"cgs_rad",PyFloat_FromDouble((1e2) ));
PyModule_AddObject(m,"cgs_solar_mass",PyFloat_FromDouble((1.98892e33) ));
PyModule_AddObject(m,"mks_speed_of_light",PyFloat_FromDouble((2.99792458e8) ));
PyModule_AddObject(m,"mks_gravitational_constant",PyFloat_FromDouble((6.67259e-11) ));
PyModule_AddObject(m,"mks_plancks_constant_h",PyFloat_FromDouble((6.6260755e-34) ));
PyModule_AddObject(m,"mks_plancks_constant_hbar",PyFloat_FromDouble((1.05457266913e-34) ));
PyModule_AddObject(m,"mks_vacuum_permeability",PyFloat_FromDouble((1.25663706144e-6) ));
PyModule_AddObject(m,"mks_astronomical_unit",PyFloat_FromDouble((1.495979e11) ));
PyModule_AddObject(m,"mks_light_year",PyFloat_FromDouble((9.46053620707e15) ));
PyModule_AddObject(m,"mks_parsec",PyFloat_FromDouble((3.08567818589e16) ));
PyModule_AddObject(m,"mks_grav_accel",PyFloat_FromDouble((9.80665e0) ));
PyModule_AddObject(m,"mks_electron_volt",PyFloat_FromDouble((1.60217733e-19) ));
PyModule_AddObject(m,"mks_mass_electron",PyFloat_FromDouble((9.10938961969e-31) ));
PyModule_AddObject(m,"mks_mass_muon",PyFloat_FromDouble((1.88353269879e-28) ));
PyModule_AddObject(m,"mks_mass_proton",PyFloat_FromDouble((1.67262307095e-27) ));
PyModule_AddObject(m,"mks_mass_neutron",PyFloat_FromDouble((1.67492862142e-27) ));
PyModule_AddObject(m,"mks_rydberg",PyFloat_FromDouble((2.17987412173e-18) ));
PyModule_AddObject(m,"mks_boltzmann",PyFloat_FromDouble((1.3806513e-23) ));
PyModule_AddObject(m,"mks_bohr_magneton",PyFloat_FromDouble((9.27401542715e-24) ));
PyModule_AddObject(m,"mks_nuclear_magneton",PyFloat_FromDouble((5.05078658357e-27) ));
PyModule_AddObject(m,"mks_electron_magnetic_moment",PyFloat_FromDouble((9.28477005945e-24) ));
PyModule_AddObject(m,"mks_proton_magnetic_moment",PyFloat_FromDouble((1.41060761072e-26) ));
PyModule_AddObject(m,"mks_molar_gas",PyFloat_FromDouble((8.31447086363e0) ));
PyModule_AddObject(m,"mks_standard_gas_volume",PyFloat_FromDouble((2.2413992e-2) ));
PyModule_AddObject(m,"mks_minute",PyFloat_FromDouble((6e1) ));
PyModule_AddObject(m,"mks_hour",PyFloat_FromDouble((3.6e3) ));
PyModule_AddObject(m,"mks_day",PyFloat_FromDouble((8.64e4) ));
PyModule_AddObject(m,"mks_week",PyFloat_FromDouble((6.048e5) ));
PyModule_AddObject(m,"mks_inch",PyFloat_FromDouble((2.54e-2) ));
PyModule_AddObject(m,"mks_foot",PyFloat_FromDouble((3.048e-1) ));
PyModule_AddObject(m,"mks_yard",PyFloat_FromDouble((9.144e-1) ));
PyModule_AddObject(m,"mks_mile",PyFloat_FromDouble((1.609344e3) ));
PyModule_AddObject(m,"mks_nautical_mile",PyFloat_FromDouble((1.852e3) ));
PyModule_AddObject(m,"mks_fathom",PyFloat_FromDouble((1.8288e0) ));
PyModule_AddObject(m,"mks_mil",PyFloat_FromDouble((2.54e-5) ));
PyModule_AddObject(m,"mks_point",PyFloat_FromDouble((3.52777777778e-4) ));
PyModule_AddObject(m,"mks_texpoint",PyFloat_FromDouble((3.51459803515e-4) ));
PyModule_AddObject(m,"mks_micron",PyFloat_FromDouble((1e-6) ));
PyModule_AddObject(m,"mks_angstrom",PyFloat_FromDouble((1e-10) ));
PyModule_AddObject(m,"mks_hectare",PyFloat_FromDouble((1e4) ));
PyModule_AddObject(m,"mks_acre",PyFloat_FromDouble((4.04685642241e3) ));
PyModule_AddObject(m,"mks_barn",PyFloat_FromDouble((1e-28) ));
PyModule_AddObject(m,"mks_liter",PyFloat_FromDouble((1e-3) ));
PyModule_AddObject(m,"mks_us_gallon",PyFloat_FromDouble((3.78541178402e-3) ));
PyModule_AddObject(m,"mks_quart",PyFloat_FromDouble((9.46352946004e-4) ));
PyModule_AddObject(m,"mks_pint",PyFloat_FromDouble((4.73176473002e-4) ));
PyModule_AddObject(m,"mks_cup",PyFloat_FromDouble((2.36588236501e-4) ));
PyModule_AddObject(m,"mks_fluid_ounce",PyFloat_FromDouble((2.95735295626e-5) ));
PyModule_AddObject(m,"mks_tablespoon",PyFloat_FromDouble((1.47867647813e-5) ));
PyModule_AddObject(m,"mks_teaspoon",PyFloat_FromDouble((4.92892159375e-6) ));
PyModule_AddObject(m,"mks_canadian_gallon",PyFloat_FromDouble((4.54609e-3) ));
PyModule_AddObject(m,"mks_uk_gallon",PyFloat_FromDouble((4.546092e-3) ));
PyModule_AddObject(m,"mks_miles_per_hour",PyFloat_FromDouble((4.4704e-1) ));
PyModule_AddObject(m,"mks_kilometers_per_hour",PyFloat_FromDouble((2.77777777778e-1) ));
PyModule_AddObject(m,"mks_knot",PyFloat_FromDouble((5.14444444444e-1) ));
PyModule_AddObject(m,"mks_pound_mass",PyFloat_FromDouble((4.5359237e-1) ));
PyModule_AddObject(m,"mks_ounce_mass",PyFloat_FromDouble((2.8349523125e-2) ));
PyModule_AddObject(m,"mks_ton",PyFloat_FromDouble((9.0718474e2) ));
PyModule_AddObject(m,"mks_metric_ton",PyFloat_FromDouble((1e3) ));
PyModule_AddObject(m,"mks_uk_ton",PyFloat_FromDouble((1.0160469088e3) ));
PyModule_AddObject(m,"mks_troy_ounce",PyFloat_FromDouble((3.1103475e-2) ));
PyModule_AddObject(m,"mks_carat",PyFloat_FromDouble((2e-4) ));
PyModule_AddObject(m,"mks_unified_atomic_mass",PyFloat_FromDouble((1.6605402e-27) ));
PyModule_AddObject(m,"mks_gram_force",PyFloat_FromDouble((9.80665e-3) ));
PyModule_AddObject(m,"mks_pound_force",PyFloat_FromDouble((4.44822161526e0) ));
PyModule_AddObject(m,"mks_kilopound_force",PyFloat_FromDouble((4.44822161526e3) ));
PyModule_AddObject(m,"mks_poundal",PyFloat_FromDouble((1.38255e-1) ));
PyModule_AddObject(m,"mks_calorie",PyFloat_FromDouble((4.1868e0) ));
PyModule_AddObject(m,"mks_btu",PyFloat_FromDouble((1.05505585262e3) ));
PyModule_AddObject(m,"mks_therm",PyFloat_FromDouble((1.05506e8) ));
PyModule_AddObject(m,"mks_horsepower",PyFloat_FromDouble((7.457e2) ));
PyModule_AddObject(m,"mks_bar",PyFloat_FromDouble((1e5) ));
PyModule_AddObject(m,"mks_std_atmosphere",PyFloat_FromDouble((1.01325e5) ));
PyModule_AddObject(m,"mks_torr",PyFloat_FromDouble((1.33322368421e2) ));
PyModule_AddObject(m,"mks_meter_of_mercury",PyFloat_FromDouble((1.33322368421e5) ));
PyModule_AddObject(m,"mks_inch_of_mercury",PyFloat_FromDouble((3.38638815789e3) ));
PyModule_AddObject(m,"mks_inch_of_water",PyFloat_FromDouble((2.4884e2) ));
PyModule_AddObject(m,"mks_psi",PyFloat_FromDouble((6.89475729317e3) ));
PyModule_AddObject(m,"mks_poise",PyFloat_FromDouble((1e-1) ));
PyModule_AddObject(m,"mks_stokes",PyFloat_FromDouble((1e-4) ));
PyModule_AddObject(m,"mks_faraday",PyFloat_FromDouble((9.6485308989e4) ));
PyModule_AddObject(m,"mks_electron_charge",PyFloat_FromDouble((1.60217733e-19) ));
PyModule_AddObject(m,"mks_gauss",PyFloat_FromDouble((1e-4) ));
PyModule_AddObject(m,"mks_stilb",PyFloat_FromDouble((1e4) ));
PyModule_AddObject(m,"mks_lumen",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"mks_lux",PyFloat_FromDouble((1e0) ));
PyModule_AddObject(m,"mks_phot",PyFloat_FromDouble((1e4) ));
PyModule_AddObject(m,"mks_footcandle",PyFloat_FromDouble((1.076e1) ));
PyModule_AddObject(m,"mks_lambert",PyFloat_FromDouble((1e4) ));
PyModule_AddObject(m,"mks_footlambert",PyFloat_FromDouble((1.07639104e1) ));
PyModule_AddObject(m,"mks_curie",PyFloat_FromDouble((3.7e10) ));
PyModule_AddObject(m,"mks_roentgen",PyFloat_FromDouble((2.58e-4) ));
PyModule_AddObject(m,"mks_rad",PyFloat_FromDouble((1e-2) ));
PyModule_AddObject(m,"mks_solar_mass",PyFloat_FromDouble((1.98892e30) ));
PyModule_AddObject(m,"num_fine_structure",PyFloat_FromDouble((7.29735307964e-3) ));
PyModule_AddObject(m,"num_avogadro",PyFloat_FromDouble((6.0221367e23) ));
